LoginCredentials class sealed

Available extensions
Annotations
  • @freezed

Constructors

LoginCredentials.oauth({required String accessToken, required String idToken})
const
factory

Properties

accessToken String
no setterinherited
copyWith → $LoginCredentialsCopyWith<LoginCredentials>
Create a copy of LoginCredentials with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
idToken String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult oauth(OAuthCredentials value)}) → TResult

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? oauth(OAuthCredentials value)?}) → TResult?

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult oauth(OAuthCredentials value)?, required TResult orElse()}) → TResult

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult oauth(String accessToken, String idToken)?, required TResult orElse()}) → TResult

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult oauth(String accessToken, String idToken)}) → TResult

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? oauth(String accessToken, String idToken)?}) → TResult?

Available on LoginCredentials, provided by the LoginCredentialsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited