User class sealed

Available extensions
Annotations
  • @freezed

Constructors

User({required String? name, required String? familyName, required String? givenName, String? basfLocalEn, String? userName, String? sub, String? upn, @JsonKey.new(name: 'picture') String? pictureUrl, String? email})
const
factory
User.fromJson(Map<String, dynamic> json)
The factory uses a normalized JSON map so that keys from both source formats are handled.
factory

Properties

basfLocalEn String?
no setterinherited
copyWith → $UserCopyWith<User>
Create a copy of User with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
familyName String?
no setterinherited
givenName String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String?
no setterinherited
pictureUrl String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub String?
no setterinherited
upn String?
no setterinherited
userId String?

Available on User, provided by the GetUserType extension

no setter
userName String?
no setterinherited

Methods

getUserType({required bool asInternal, required bool asPartner, required bool asExternal}) UserType

Available on User, provided by the GetUserType extension

map<TResult extends Object?>(TResult $default(_User value)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_User value)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_User value)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? name, String? familyName, String? givenName, String? basfLocalEn, String? userName, String? sub, String? upn, String? pictureUrl, String? email)?, {required TResult orElse()}) → TResult

Available on User, provided by the UserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this User to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? name, String? familyName, String? givenName, String? basfLocalEn, String? userName, String? sub, String? upn, String? pictureUrl, String? email)) → TResult

Available on User, provided by the UserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? name, String? familyName, String? givenName, String? basfLocalEn, String? userName, String? sub, String? upn, String? pictureUrl, String? email)?) → TResult?

Available on User, provided by the UserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited