UserSession class sealed

Available extensions
Annotations
  • @freezed

Constructors

UserSession({User? user, DateTime? expirationDate})
const
factory
UserSession.fromJson(Json json)
factory

Properties

copyWith → $UserSessionCopyWith<UserSession>
Create a copy of UserSession with the given fields replaced by the non-null parameter values.
no setterinherited
expirationDate DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user User?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_UserSession value)) → TResult

Available on UserSession, provided by the UserSessionPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_UserSession value)?) → TResult?

Available on UserSession, provided by the UserSessionPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_UserSession value)?, {required TResult orElse()}) → TResult

Available on UserSession, provided by the UserSessionPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(User? user, DateTime? expirationDate)?, {required TResult orElse()}) → TResult

Available on UserSession, provided by the UserSessionPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UserSession to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(User? user, DateTime? expirationDate)) → TResult

Available on UserSession, provided by the UserSessionPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(User? user, DateTime? expirationDate)?) → TResult?

Available on UserSession, provided by the UserSessionPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited