ToItem class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ToItem({required String itemNumber, String? refDocPos, String? orderNumber, String? customerMaterial, String? plant, String? batchNumber, @DateConverter() DateTime? batchProddate, bool? batchReqindctr, String? storageLocation, String? itemCategory, String? batchMainItem, String? salesUnit, String? deliveryQty, String? uom, @JsonKey.new(name: 'Interco_po') String? intercoPo, String? intercoPoitem, @DateConverter() DateTime? expiryDate, ToMaterial? toMaterial, ToPickQuantity? toPickQuantity, List<
UnitOfMeasuresDto> ? recalculationUOMs, @Default.new([]) List<HuDetails> deliveryHUs}) -
constfactory
-
ToItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- batchMainItem → String?
-
no setterinherited
- batchNumber → String?
-
no setterinherited
- batchProddate → DateTime?
-
no setterinherited
- batchReqindctr → bool?
-
no setterinherited
-
copyWith
→ $ToItemCopyWith<
ToItem> -
Create a copy of ToItem
with the given fields replaced by the non-null parameter values.
no setterinherited
- customerMaterial → String?
-
no setterinherited
-
deliveryHUs
→ List<
HuDetails> -
no setterinherited
- deliveryItemQuantity → double
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - deliveryMeasure → String
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - deliveryQty → String?
-
no setterinherited
- expiryDate → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- intercoPo → String?
-
no setterinherited
- intercoPoitem → String?
-
no setterinherited
- isFullPicked → bool
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - isHURelevant → bool
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - itemCategory → String?
-
no setterinherited
- itemNumber → String
-
no setterinherited
- openItemQty → double
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - orderNumber → String?
-
no setterinherited
- pickupQty → double
-
Available on ToItem, provided by the DeliveryItemExtension extension
no setter - plant → String?
-
no setterinherited
-
recalculationUOMs
→ List<
UnitOfMeasuresDto> ? -
no setterinherited
- refDocPos → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salesUnit → String?
-
no setterinherited
- storageLocation → String?
-
no setterinherited
- toMaterial → ToMaterial?
-
no setterinherited
- toPickQuantity → ToPickQuantity?
-
no setterinherited
- uom → String?
-
no setterinherited
Methods
-
getDelivQtyString(
{required String regionString}) → String -
Available on ToItem, provided by the DeliveryItemExtension extension
-
getPickupQtyString(
{required String regionString}) → String -
Available on ToItem, provided by the DeliveryItemExtension extension
-
map<
TResult extends Object?> (TResult $default(_ToItem value)) → TResult -
Available on ToItem, provided by the ToItemPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ToItem value)?) → TResult? -
Available on ToItem, provided by the ToItemPatterns extension
A variant ofmapthat fallback to returningnull. -
materialAndBatchOk(
{required String material, required String? batch}) → bool -
Available on ToItem, provided by the DeliveryItemExtension extension
-
maybeMap<
TResult extends Object?> (TResult $default(_ToItem value)?, {required TResult orElse()}) → TResult -
Available on ToItem, provided by the ToItemPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String itemNumber, String? refDocPos, String? orderNumber, String? customerMaterial, String? plant, String? batchNumber, DateTime? batchProddate, bool? batchReqindctr, String? storageLocation, String? itemCategory, String? batchMainItem, String? salesUnit, String? deliveryQty, String? uom, String? intercoPo, String? intercoPoitem, DateTime? expiryDate, ToMaterial? toMaterial, ToPickQuantity? toPickQuantity, List< UnitOfMeasuresDto> ? recalculationUOMs, List<HuDetails> deliveryHUs)?, {required TResult orElse()}) → TResult -
Available on ToItem, provided by the ToItemPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDeliveryQuantityUpdateJson(
{required double quantity}) → Json -
Available on ToItem, provided by the DeliveryItemExtension extension
-
toJson(
) → Map< String, dynamic> -
Serializes this ToItem to a JSON map.
inherited
-
toPickupQuantityUpdateJson(
{required double quantity}) → Json -
Available on ToItem, provided by the DeliveryItemExtension extension
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String itemNumber, String? refDocPos, String? orderNumber, String? customerMaterial, String? plant, String? batchNumber, DateTime? batchProddate, bool? batchReqindctr, String? storageLocation, String? itemCategory, String? batchMainItem, String? salesUnit, String? deliveryQty, String? uom, String? intercoPo, String? intercoPoitem, DateTime? expiryDate, ToMaterial? toMaterial, ToPickQuantity? toPickQuantity, List< UnitOfMeasuresDto> ? recalculationUOMs, List<HuDetails> deliveryHUs)) → TResult -
Available on ToItem, provided by the ToItemPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String itemNumber, String? refDocPos, String? orderNumber, String? customerMaterial, String? plant, String? batchNumber, DateTime? batchProddate, bool? batchReqindctr, String? storageLocation, String? itemCategory, String? batchMainItem, String? salesUnit, String? deliveryQty, String? uom, String? intercoPo, String? intercoPoitem, DateTime? expiryDate, ToMaterial? toMaterial, ToPickQuantity? toPickQuantity, List< UnitOfMeasuresDto> ? recalculationUOMs, List<HuDetails> deliveryHUs)?) → TResult? -
Available on ToItem, provided by the ToItemPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited