ToMaterial class sealed

Available extensions
Annotations
  • @freezed

Constructors

ToMaterial({required String material, @ToTextListConverter() @Default.new([]) List<ToText> toText})
const
factory
ToMaterial.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ToMaterialCopyWith<ToMaterial>
Create a copy of ToMaterial with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
material String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toText List<ToText>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ToMaterial value)) → TResult

Available on ToMaterial, provided by the ToMaterialPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ToMaterial value)?) → TResult?

Available on ToMaterial, provided by the ToMaterialPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ToMaterial value)?, {required TResult orElse()}) → TResult

Available on ToMaterial, provided by the ToMaterialPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String material, List<ToText> toText)?, {required TResult orElse()}) → TResult

Available on ToMaterial, provided by the ToMaterialPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ToMaterial to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String material, List<ToText> toText)) → TResult

Available on ToMaterial, provided by the ToMaterialPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String material, List<ToText> toText)?) → TResult?

Available on ToMaterial, provided by the ToMaterialPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited