PackingInstruction class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
PackingInstruction({@JsonKey.new(name: 'packing_instruction_no') required String piNumber, String? description, String? height, String? width, String? length, String? innerHeight, String? innerWidth, String? innerLength, String? unitDimension, String? unitDimensionIso, String? sizeFix, String? totalVolume, String? loadingVolume, String? allowedVolume, String? volumeUnit, String? volumeUnitIso, String? tareVolume, String? tareVolumeUnit, String? tareVolumeUnitIso, String? volumeFix, String? volumeTolerance, String? totalWeight, String? loadWeight, String? allowedWeight, String? maxUnitOfWeight, String? maxUnitOfWeightIso, String? tareWeight, String? unitOfWeight, String? unitOfWeightIso, String? weightFix, String? weightTolerance, String? allowedLoad, String? stackingFactor, String? printNoShipLabel, String? closedBox, String? checkProfile, String? palletType, int? numberOfUnitsPerPallet, String? sirex, @JsonKey.new(name: 'NP_PI_HeaderToPosition') required List<
NPPIHeaderPosition> npPIHeaderPositions}) -
constfactory
- PackingInstruction.fromJson(Json json)
-
factory
Properties
- allowedLoad → String?
-
no setterinherited
- allowedVolume → String?
-
no setterinherited
- allowedWeight → String?
-
no setterinherited
- checkProfile → String?
-
no setterinherited
- closedBox → String?
-
no setterinherited
-
copyWith
→ $PackingInstructionCopyWith<
PackingInstruction> -
Create a copy of PackingInstruction
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String?
-
no setterinherited
- innerHeight → String?
-
no setterinherited
- innerLength → String?
-
no setterinherited
- innerWidth → String?
-
no setterinherited
- length → String?
-
no setterinherited
- loadingVolume → String?
-
no setterinherited
- loadWeight → String?
-
no setterinherited
- maxUnitOfWeight → String?
-
no setterinherited
- maxUnitOfWeightIso → String?
-
no setterinherited
-
npPIHeaderPositions
→ List<
NPPIHeaderPosition> -
no setterinherited
- numberOfUnitsPerPallet → int?
-
no setterinherited
- palletType → String?
-
no setterinherited
- piNumber → String
-
no setterinherited
- printNoShipLabel → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sirex → String?
-
no setterinherited
- sizeFix → String?
-
no setterinherited
- stackingFactor → String?
-
no setterinherited
- tareVolume → String?
-
no setterinherited
- tareVolumeUnit → String?
-
no setterinherited
- tareVolumeUnitIso → String?
-
no setterinherited
- tareWeight → String?
-
no setterinherited
- totalVolume → String?
-
no setterinherited
- totalWeight → String?
-
no setterinherited
- unitDimension → String?
-
no setterinherited
- unitDimensionIso → String?
-
no setterinherited
- unitOfWeight → String?
-
no setterinherited
- unitOfWeightIso → String?
-
no setterinherited
- volumeFix → String?
-
no setterinherited
- volumeTolerance → String?
-
no setterinherited
- volumeUnit → String?
-
no setterinherited
- volumeUnitIso → String?
-
no setterinherited
- weightFix → String?
-
no setterinherited
- weightTolerance → String?
-
no setterinherited
- width → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PackingInstruction value)) → TResult -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PackingInstruction value)?) → TResult? -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PackingInstruction value)?, {required TResult orElse()}) → TResult -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String piNumber, String? description, String? height, String? width, String? length, String? innerHeight, String? innerWidth, String? innerLength, String? unitDimension, String? unitDimensionIso, String? sizeFix, String? totalVolume, String? loadingVolume, String? allowedVolume, String? volumeUnit, String? volumeUnitIso, String? tareVolume, String? tareVolumeUnit, String? tareVolumeUnitIso, String? volumeFix, String? volumeTolerance, String? totalWeight, String? loadWeight, String? allowedWeight, String? maxUnitOfWeight, String? maxUnitOfWeightIso, String? tareWeight, String? unitOfWeight, String? unitOfWeightIso, String? weightFix, String? weightTolerance, String? allowedLoad, String? stackingFactor, String? printNoShipLabel, String? closedBox, String? checkProfile, String? palletType, int? numberOfUnitsPerPallet, String? sirex, List< NPPIHeaderPosition> npPIHeaderPositions)?, {required TResult orElse()}) → TResult -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PackingInstruction to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String piNumber, String? description, String? height, String? width, String? length, String? innerHeight, String? innerWidth, String? innerLength, String? unitDimension, String? unitDimensionIso, String? sizeFix, String? totalVolume, String? loadingVolume, String? allowedVolume, String? volumeUnit, String? volumeUnitIso, String? tareVolume, String? tareVolumeUnit, String? tareVolumeUnitIso, String? volumeFix, String? volumeTolerance, String? totalWeight, String? loadWeight, String? allowedWeight, String? maxUnitOfWeight, String? maxUnitOfWeightIso, String? tareWeight, String? unitOfWeight, String? unitOfWeightIso, String? weightFix, String? weightTolerance, String? allowedLoad, String? stackingFactor, String? printNoShipLabel, String? closedBox, String? checkProfile, String? palletType, int? numberOfUnitsPerPallet, String? sirex, List< NPPIHeaderPosition> npPIHeaderPositions)) → TResult -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String piNumber, String? description, String? height, String? width, String? length, String? innerHeight, String? innerWidth, String? innerLength, String? unitDimension, String? unitDimensionIso, String? sizeFix, String? totalVolume, String? loadingVolume, String? allowedVolume, String? volumeUnit, String? volumeUnitIso, String? tareVolume, String? tareVolumeUnit, String? tareVolumeUnitIso, String? volumeFix, String? volumeTolerance, String? totalWeight, String? loadWeight, String? allowedWeight, String? maxUnitOfWeight, String? maxUnitOfWeightIso, String? tareWeight, String? unitOfWeight, String? unitOfWeightIso, String? weightFix, String? weightTolerance, String? allowedLoad, String? stackingFactor, String? printNoShipLabel, String? closedBox, String? checkProfile, String? palletType, int? numberOfUnitsPerPallet, String? sirex, List< NPPIHeaderPosition> npPIHeaderPositions)?) → TResult? -
Available on PackingInstruction, provided by the PackingInstructionPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited