SSCCUnitDto class sealed

Available extensions
Annotations
  • @freezed

Constructors

SSCCUnitDto({@JsonKey.new(includeToJson: false) required String unitId, @ItemIdTypeJsonConverter() required ItemIdType idType, @JsonKey.new(includeToJson: false) required String unitVersion, required String otherStructure, required String processStep, @JsonKey.new(includeToJson: false) required DateTime createdAt, required String packingLevel, required String user, required SourceIdentifier sourceIdentifier})
const
factory
SSCCUnitDto.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $SSCCUnitDtoCopyWith<SSCCUnitDto>
Create a copy of SSCCUnitDto with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
idType ItemIdType
no setterinherited
otherStructure String
no setterinherited
packingLevel String
no setterinherited
processStep String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIdentifier SourceIdentifier
no setterinherited
unitId String
no setterinherited
unitVersion String
no setterinherited
user String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SSCCUnitDto value)) → TResult

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SSCCUnitDto value)?) → TResult?

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SSCCUnitDto value)?, {required TResult orElse()}) → TResult

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String unitId, ItemIdType idType, String unitVersion, String otherStructure, String processStep, DateTime createdAt, String packingLevel, String user, SourceIdentifier sourceIdentifier)?, {required TResult orElse()}) → TResult

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SSCCUnitDto to a JSON map.
inherited
toSSCCUnit({UnitServer? server}) → UnitSSCC

Available on SSCCUnitDto, provided by the SSCCDtoExtension extension

toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String unitId, ItemIdType idType, String unitVersion, String otherStructure, String processStep, DateTime createdAt, String packingLevel, String user, SourceIdentifier sourceIdentifier)) → TResult

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String unitId, ItemIdType idType, String unitVersion, String otherStructure, String processStep, DateTime createdAt, String packingLevel, String user, SourceIdentifier sourceIdentifier)?) → TResult?

Available on SSCCUnitDto, provided by the SSCCUnitDtoPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited