StringExtension extension
- on
Properties
- doubleValue → double
-
Available on String, provided by the StringExtension extension
no setter - tryConvertToQuantity → String
-
Available on String, provided by the StringExtension extension
no setter
Methods
-
addPatternAt(
int index, String pattern) → String -
Available on String, provided by the StringExtension extension
-
compareNumberString(
String? numberString) → bool -
Available on String, provided by the StringExtension extension
-
convertToQuantity(
{String? regionString, bool removeZeroes = false, bool replaceComasAndAddDots = false}) → String -
Available on String, provided by the StringExtension extension
This getter returns a well formatted quantity as String, if the String can be parsed to double If the value can't be parsed, it just returns its value -
getLastSymbols(
int symbolsAmount) → String -
Available on String, provided by the StringExtension extension
-
matchWithTwoZeroesWrapped(
String secondString) → bool -
Available on String, provided by the StringExtension extension
-
padZeroes(
int numberLength) → String -
Available on String, provided by the StringExtension extension
-
quantityFromString(
{String? regionString}) → double? -
Available on String, provided by the StringExtension extension
Parses numbers written with either EU or US separators. Rules: -
removeLeadingZeroes(
) → String -
Available on String, provided by the StringExtension extension
-
removeSpecialSymbols(
) → String -
Available on String, provided by the StringExtension extension
-
toKebabCase(
) → String -
Available on String, provided by the StringExtension extension
-
toTitleCase(
) → String -
Available on String, provided by the StringExtension extension
-
withParams(
Map< String, dynamic> params) → String -
Available on String, provided by the StringExtension extension
-
wrapTwoZeroes(
) → String -
Available on String, provided by the StringExtension extension