Checkpoint class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Checkpoint({required String checklistResultId, required String groupId, required String checkpointId, required String checkpointNo, required String checkpointName, required String checkpointText, required int sequence, @CheckpointTypeConverter() required CheckpointType checkpointType, required int numberOfValues, required String actionOk, required String actionNotOk, required String actionNa, required int sequenceOk, required int sequenceNotOk, required int sequenceNa, required bool uploadEnabled, required bool commentEnabled, required bool commentReqOk, required bool commentReqNotOk, required bool commentReqNa, required bool enabled, required String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, @Default.new('') String verifRefvalFlt1, @Default.new('') String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, @Default.new('') String verifValFlt, bool? confirmActivity, @Default.new('') String refMode, @Default.new('') String refDocField, @Default.new('') String refDocFieldType, @Default.new('') String refDocField2, @Default.new('') String refDocField2Type, @CheckpointVerificationTypeConverter() CheckpointVerificationType? verifType, @CheckpointVerificationRuleConverter() CheckpointVerificationRule? verifRule, @Default.new('') String verifRefvalUom, @JsonKey.new(includeFromJson: false, includeToJson: false) @Default.new('') String verificationValue1, @JsonKey.new(includeFromJson: false, includeToJson: false) @Default.new('') String verificationValue2, @Default.new('') String verifRefvalChar1, @Default.new('') String verifRefvalChar2, @Default.new('') String messageOkLongtext, @Default.new('') String messageNotOkLongtext, @Default.new('') String messageNaLongtext, @Default.new('') String commentString, @CheckpointGroupStatusConverter() ChecklistGroupStatus? groupStatus, @CheckpointGroupStatusConverter() ChecklistGroupStatus? status, @CheckpointStatusConverter() CheckpointStatus? isOk, @JsonKey.new(includeFromJson: false, includeToJson: false) @Default.new(CheckpointEditingStatus.initial) CheckpointEditingStatus checkpointEditingStatus, @Default.new('') String freetext1, @Default.new('') String freetext2, @DateConverter() DateTime? date1, @DateConverter() DateTime? date2, @Default.new('') String docFieldRef1, @Default.new('') String docFieldRef2, @Default.new('') String verifValUom, @Default.new('') String verifValChar, @Default.new('') String refCodecat, @Default.new('') String refCodetype, @Default.new('') String refCodeId, @Default.new('') String listselValue, @Default.new('') String refMaVal1, @Default.new('') String refMaVal2, @Default.new('') String refDocfieldVal1, @Default.new('') String refDocfieldVal2, @Default.new('') String acknowledge, @Default.new('') String requestedAction, @DateConverter() DateTime? lastChange, @DeferredConverter() @Default.new('') String group, @CheckpointSignatureConverter() @Default.new([]) List<
CheckpointSignature> signatures, @CheckpointAttachmentConverter() @Default.new([]) List<CheckpointAttachment> attachments, @CheckpointListValueConverter() @Default.new([]) List<CheckpointListValue> listValues, @CheckpointCodesConverter() @Default.new([]) List<String> codes, @JsonKey.new(includeFromJson: false, includeToJson: false) @Default.new([]) List<CheckpointValidationError> validationErrors}) -
constfactory
- Checkpoint.fromJson(Json json)
-
factory
Properties
- acknowledge → String
-
no setterinherited
- actionNa → String
-
no setterinherited
- actionNotOk → String
-
no setterinherited
- actionOk → String
-
no setterinherited
- activityId → String
-
no setterinherited
-
attachments
→ List<
CheckpointAttachment> -
no setterinherited
-
availableOkStatuses
→ List<
CheckpointStatus> -
Available on Checkpoint, provided by the CheckpointExtension extension
no setter - checklistResultId → String
-
no setterinherited
- checkpointEditingStatus → CheckpointEditingStatus
-
no setterinherited
- checkpointId → String
-
no setterinherited
- checkpointName → String
-
no setterinherited
- checkpointNo → String
-
no setterinherited
- checkpointText → String
-
no setterinherited
- checkpointType → CheckpointType
-
no setterinherited
-
codes
→ List<
String> -
no setterinherited
- commentEnabled → bool
-
no setterinherited
- commentReqNa → bool
-
no setterinherited
- commentReqNotOk → bool
-
no setterinherited
- commentReqOk → bool
-
no setterinherited
- commentString → String
-
no setterinherited
- confirmActivity → bool?
-
no setterinherited
- confirmImage → bool?
-
no setterinherited
-
copyWith
→ $CheckpointCopyWith<
Checkpoint> -
Create a copy of Checkpoint
with the given fields replaced by the non-null parameter values.
no setterinherited
- date1 → DateTime?
-
no setterinherited
- date2 → DateTime?
-
no setterinherited
- docFieldRef1 → String
-
no setterinherited
- docFieldRef2 → String
-
no setterinherited
- enabled → bool
-
no setterinherited
- freetext1 → String
-
no setterinherited
- freetext2 → String
-
no setterinherited
- group → String
-
no setterinherited
- groupId → String
-
no setterinherited
- groupStatus → ChecklistGroupStatus?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompleted → bool
-
Available on Checkpoint, provided by the CheckpointExtension extension
no setter - isGroupCompleted → bool
-
Available on Checkpoint, provided by the CheckpointExtension extension
no setter - isOk → CheckpointStatus?
-
no setterinherited
- lastChange → DateTime?
-
no setterinherited
- listselValue → String
-
no setterinherited
-
listValues
→ List<
CheckpointListValue> -
no setterinherited
- messageNaLongtext → String
-
no setterinherited
- messageNotOkLongtext → String
-
no setterinherited
- messageOkLongtext → String
-
no setterinherited
- number1 → int?
-
no setterinherited
- number2 → int?
-
no setterinherited
- numberOfValues → int
-
no setterinherited
- refCodecat → String
-
no setterinherited
- refCodeId → String
-
no setterinherited
- refCodetype → String
-
no setterinherited
- refDocField → String
-
no setterinherited
- refDocField2 → String
-
no setterinherited
- refDocField2Type → String
-
no setterinherited
- refDocFieldType → String
-
no setterinherited
- refDocfieldVal1 → String
-
no setterinherited
- refDocfieldVal2 → String
-
no setterinherited
- refMaVal1 → String
-
no setterinherited
- refMaVal2 → String
-
no setterinherited
- refMode → String
-
no setterinherited
- requestedAction → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequence → int
-
no setterinherited
- sequenceNa → int
-
no setterinherited
- sequenceNotOk → int
-
no setterinherited
- sequenceOk → int
-
no setterinherited
-
signatures
→ List<
CheckpointSignature> -
no setterinherited
- status → ChecklistGroupStatus?
-
no setterinherited
- uploadEnabled → bool
-
no setterinherited
-
validationErrors
→ List<
CheckpointValidationError> -
no setterinherited
- verificationValue1 → String
-
no setterinherited
- verificationValue2 → String
-
no setterinherited
- verifRefvalChar1 → String
-
no setterinherited
- verifRefvalChar2 → String
-
no setterinherited
- verifRefvalFlt1 → String
-
no setterinherited
- verifRefvalFlt2 → String
-
no setterinherited
- verifRefvalInt1 → int?
-
no setterinherited
- verifRefvalInt2 → int?
-
no setterinherited
- verifRefvalUom → String
-
no setterinherited
- verifRule → CheckpointVerificationRule?
-
no setterinherited
- verifType → CheckpointVerificationType?
-
no setterinherited
- verifValChar → String
-
no setterinherited
- verifValFlt → String
-
no setterinherited
- verifValInt → int?
-
no setterinherited
- verifValUom → String
-
no setterinherited
Methods
-
getTypeTitle(
BuildContext context) → String -
Available on Checkpoint, provided by the CheckpointExtension extension
-
map<
TResult extends Object?> (TResult $default(_Checkpoint value)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Checkpoint value)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Checkpoint value)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List< CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCheckpointMergeDataJson(
{required InnerChecklist checklist, required bool isFinalConfirmation}) → Json -
Available on Checkpoint, provided by the CheckpointExtension extension
-
toJson(
) → Map< String, dynamic> -
Serializes this Checkpoint to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List< CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List< CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited