CheckpointPatterns extension

Adds pattern-matching-related methods to Checkpoint.

on

Methods

map<TResult extends Object?>(TResult $default(_Checkpoint value)) → TResult

Available on Checkpoint, provided by the CheckpointPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Checkpoint value)?) → TResult?

Available on Checkpoint, provided by the CheckpointPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Checkpoint value)?, {required TResult orElse()}) → TResult

Available on Checkpoint, provided by the CheckpointPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List<CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)?, {required TResult orElse()}) → TResult

Available on Checkpoint, provided by the CheckpointPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List<CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)) → TResult

Available on Checkpoint, provided by the CheckpointPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String checklistResultId, String groupId, String checkpointId, String checkpointNo, String checkpointName, String checkpointText, int sequence, CheckpointType checkpointType, int numberOfValues, String actionOk, String actionNotOk, String actionNa, int sequenceOk, int sequenceNotOk, int sequenceNa, bool uploadEnabled, bool commentEnabled, bool commentReqOk, bool commentReqNotOk, bool commentReqNa, bool enabled, String activityId, bool? confirmImage, int? verifRefvalInt1, int? verifRefvalInt2, String verifRefvalFlt1, String verifRefvalFlt2, int? number1, int? number2, int? verifValInt, String verifValFlt, bool? confirmActivity, String refMode, String refDocField, String refDocFieldType, String refDocField2, String refDocField2Type, CheckpointVerificationType? verifType, CheckpointVerificationRule? verifRule, String verifRefvalUom, String verificationValue1, String verificationValue2, String verifRefvalChar1, String verifRefvalChar2, String messageOkLongtext, String messageNotOkLongtext, String messageNaLongtext, String commentString, ChecklistGroupStatus? groupStatus, ChecklistGroupStatus? status, CheckpointStatus? isOk, CheckpointEditingStatus checkpointEditingStatus, String freetext1, String freetext2, DateTime? date1, DateTime? date2, String docFieldRef1, String docFieldRef2, String verifValUom, String verifValChar, String refCodecat, String refCodetype, String refCodeId, String listselValue, String refMaVal1, String refMaVal2, String refDocfieldVal1, String refDocfieldVal2, String acknowledge, String requestedAction, DateTime? lastChange, String group, List<CheckpointSignature> signatures, List<CheckpointAttachment> attachments, List<CheckpointListValue> listValues, List<String> codes, List<CheckpointValidationError> validationErrors)?) → TResult?

Available on Checkpoint, provided by the CheckpointPatterns extension

A variant of when that fallback to returning null