BasfLogicLocalizations class abstract

Callers can lookup localized strings with an instance of BasfLogicLocalizations returned by BasfLogicLocalizations.of(context).

Applications need to include BasfLogicLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'localizations/basf_logic_localizations.dart';

return MaterialApp(
  localizationsDelegates: BasfLogicLocalizations.localizationsDelegates,
  supportedLocales: BasfLogicLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the BasfLogicLocalizations.supportedLocales property.

Implementers

Constructors

BasfLogicLocalizations(String locale)

Properties

aiCode10 String
No description provided for @aiCode10.
no setter
aiCode21 String
No description provided for @aiCode21.
no setter
aiCode240 String
No description provided for @aiCode240.
no setter
aiCode241 String
No description provided for @aiCode241.
no setter
aiCode8008 String
No description provided for @aiCode8008.
no setter
aiCode91 String
No description provided for @aiCode91.
no setter
aiCode92 String
No description provided for @aiCode92.
no setter
aiCode99 String
No description provided for @aiCode99.
no setter
allItemsBookedInfo String
No description provided for @allItemsBookedInfo.
no setter
deliveryDoesNotExist String
No description provided for @deliveryDoesNotExist.
no setter
envMarking String
No description provided for @envMarking.
no setter
envMarkingUKTax String
No description provided for @envMarkingUKTax.
no setter
errorCORS String
No description provided for @errorCORS.
no setter
errorHintShare String
No description provided for @errorHintShare.
no setter
failedToGetUserDetailsFromToken String
No description provided for @failedToGetUserDetailsFromToken.
no setter
hashCode int
The hash code for this object.
no setterinherited
localeName String
final
loginErrorTokenExpired String
No description provided for @loginErrorTokenExpired.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanCodeErrorInvalid String
No description provided for @scanCodeErrorInvalid.
no setter
scanCodeErrorNull String
No description provided for @scanCodeErrorNull.
no setter
shipmentDoesNotExist String
No description provided for @shipmentDoesNotExist.
no setter
somethingWentWrong String
No description provided for @somethingWentWrong.
no setter
timeoutErrorInfo String
No description provided for @timeoutErrorInfo.
no setter
uncode String
No description provided for @uncode.
no setter
userDetailsFromToken String
No description provided for @userDetailsFromToken.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) BasfLogicLocalizations

Constants

delegate → const LocalizationsDelegate<BasfLogicLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.