AuthRepo class

Constructors

AuthRepo({required AuthProvider authProvider})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userSession UserSession
getter/setter pair

Methods

authenticate({AuthorizationTokenResponse? tokenResponse, required String clientID, required AuthEndpointsData authEndpointsData, required DioClient microsoftDioClient, Options? getUserDetailsOptions, String? staticRefreshToken}) Future<UserSession>
authorizeAndExchangeCode({required String clientID, required AuthEndpointsData authEndpointsData}) Future<AuthorizationTokenResponse>
getMicrosoftAccessToken({required String clientIDIdepack, required String clientSecret, required String tokenEndpoint, Json? getMSAccessTokenExtra}) Future<String?>
getPhoto({required DioClient dioClient, required User user, Json? getUserPhotoExtra}) Future<Uint8List?>
getRefreshedAuthTokens({required String clientID, required AuthEndpointsData authEndpointsData, String? staticRefreshToken}) Future<TokenResponse?>
getTokensFromExternalBrowser({required String clientID, required AuthEndpointsData authEndpointsData, Duration timeout = const Duration(seconds: 45)}) Future<AuthorizationTokenResponse>
This code is for using the system browser instead of the in app web view (custom chrome tab). This is necessary, because on the SOTI managed devices, the cache of the custom chrome tab is not cleared after logout from the MUA app.
getUserInfo({required String token, required DioClient microsoftDioClient, required String userInfoEndpoint, Options? getUserDetailsOptions}) Future<User>
initUserSession({required String clientID, required DioClient microsoftDioClient, required AuthEndpointsData authEndpointsData, String? staticRefreshToken, Options? getUserDetailsOptions}) Future<UserSession?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveAuthSessionTokens({required String accessToken, required String refreshToken, required String idToken}) Future<void>
signIn({required String clientID, required DioClient microsoftDioClient, required AuthEndpointsData authEndpointsData, bool useExternalBrowserOnAndroid = true, Duration timeout = const Duration(seconds: 15), Options? getUserDetailsOptions}) Future<UserSession>
signOut() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited