basf_logic_components library
This library is for logic
Classes
- AlphanumericTextInputFormatter
- AndroidBuildVersion
-
Version values of the current Android operating system build derived from
android.os.Build.VERSION. - AndroidDeviceInfo
-
Information derived from
android.os.Build. - AuthCredentials
- AuthEndpointsData
- AuthHelper
- AuthProvider
- AuthRepo
- BackgroundTransformer
- The default Transformer for Dio.
- BarcodeData
- BarcodeInfo
- BarcodeMapper
- BarcodesDictionary
- BarcodeUtils
- BaseDeviceInfo
- The base class for platform's device info.
- BaseOptions
-
A set of base settings for each
Dio(). BaseOptions and Options will be merged into one RequestOptions before sending the requests. See Options.compose. - BasfLogicLocalizations
-
Callers can lookup localized strings with an instance of BasfLogicLocalizations
returned by
BasfLogicLocalizations.of(context). - BasfLogicLocalizationsDe
-
The translations for German (
de). - BasfLogicLocalizationsDeRlp
-
The translations for German (
de_rlp). - BasfLogicLocalizationsEn
-
The translations for English (
en). - BasfLogicLocalizationUtils
- BrowserConfiguration
- Additional configuration options for LaunchMode.inAppBrowserView
- CancelToken
- Controls cancellation of Dio's requests.
- Checklist
- ChecklistApiProvider
- ChecklistCard
- ChecklistCatalogCubit
- ChecklistCatalogDocument
- ChecklistCatalogRouteArgs
- ChecklistCatalogScreen
- ChecklistCatalogState
- ChecklistDebugCubit
- ChecklistDebugDetailsScreen
- ChecklistDebugListScreen
- ChecklistDebugScreen
- ChecklistDebugState
- ChecklistDoc
- ChecklistDocModalLayout
- ChecklistDocTile
- ChecklistDto
- ChecklistEndpoints
- ChecklistGroupTile
- ChecklistModalLayout
- ChecklistProcessCubit
- ChecklistRedirectScreen
- ChecklistRepo
- ChecklistReservationItem
- ChecklistSearchCubit
- ChecklistSearchScreen
- ChecklistSearchState
- ChecklistTile
- Checkpoint
- CheckpointApiProvider
- CheckpointAttachment
- CheckpointAttachmentConverter
- CheckpointCodesConverter
- CheckpointCommentField
- CheckpointDatePicker
- CheckpointDocumentFieldLayout
- CheckpointFileUploadArea
- CheckpointGroupStatusConverter
- CheckpointListValue
- CheckpointListValueConverter
- CheckpointMenuButton
- CheckpointRepo
- CheckpointsBackModalWarning
- CheckpointsConverter
- CheckpointSegmentedButtons
- CheckpointService
- CheckpointsGroup
- CheckpointsGroupDto
- CheckpointsGroupsCubit
- CheckpointsGroupsScreen
- CheckpointsGroupsState
- CheckpointSignature
- CheckpointSignatureConverter
- CheckpointsManagementCubit
- CheckpointsManagementState
- CheckpointsScreen
- CheckpointStatusConverter
- CheckpointTile
- CheckpointTileDateLayout
- CheckpointTileFreetextLayout
- CheckpointTileInputVerificationLayout
- CheckpointTileListSelectionLayout
- CheckpointTileNumericalValueLayout
- CheckpointTileSignatureLayout
- CheckpointToggleButton
- CheckpointTypeConverter
- CheckpointVerificationRuleConverter
- CheckpointVerificationTypeConverter
- CheckService
- CreateChecklistButton
- CrossSessionCheckpointWarning
- DateConverter
- DefaultRetryEvaluator
- DeferredConverter
- Delivery
- DeliveryApiProvider
- DeliveryBookingHelper
- DeliveryBundle
- DeliveryConverter
- DeliveryEndpoints
- DeliveryRepo
- DeliveryService
- DeviceInfoPlugin
- Provides device and operating system information.
- DeviceInfoPlusLinuxPlugin
-
See
DeviceInfoPlatform - DeviceInfoPlusWindowsPlugin
-
The Windows implementation of
DeviceInfoPlatform. - DeviceLocale
- Dio
- Dio enables you to make HTTP requests easily.
- DioClient
- DioMixin
- Endpoints
- ErrorInterceptorHandler
- The handler for interceptors to handle error occurred during the request.
- FormData
- A class to create readable "multipart/form-data" streams. It can be used to submit forms and file uploads to http server.
- FusedTransformer
- A Transformer that has a fast path for decoding UTF8-encoded JSON. If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions, this transformer is significantly faster than the default SyncTransformer and the BackgroundTransformer. This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response, which is faster than decoding the utf8-encoded JSON in two separate steps, since Dart uses a special fast decoder for this case. See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
- GoodsReceiptRequirement
- Headers
- The headers class for requests and responses.
- HttpClientAdapter
-
HttpAdapteris a bridge between Dio and HttpClient. - HUApiProvider
- HuCreationData
- HuDetails
- HUEndpoints
- HuHistory
- HuItem
- HuItemPackData
- HuPackData
- HuRepo
- HuStatus
- InnerChecklist
- Interceptor
- Interceptor helps to deal with RequestOptions, Response, and DioException during the lifecycle of a request before it reaches users.
- Interceptors
- A Queue-Model list for Interceptors.
- InterceptorsWrapper
- A helper class to create interceptors in ease.
- InterpreterData
- IosDeviceInfo
-
Information derived from
UIDevice. - IosUtsname
-
Information derived from
utsname. See http://pubs.opengroup.org/onlinepubs/7908799/xsh/sysutsname.h.html for details. - ItemIdTypeJsonConverter
- ItemTitle
- ItemUnitDto
- LinuxDeviceInfo
- Device information for a Linux system.
-
ListParam<
T> - Indicates a param being used as queries or form data, and how does it gets formatted.
- LoadDocApiProvider
- LoadDocDeliveryHandlingUnit
- LoadDocDeliveryItem
- LoadDocDoc
- LoadDocRepo
- LoadDocs
- LoadDocTransportRelatedDelivery
- LoginCredentials
- LogInterceptor
- LogInterceptor is used to print logs during network requests. It should be the last interceptor added, otherwise modifications by following interceptors will not be logged. This is because the execution of interceptors is in the order of addition.
- MacOsDeviceInfo
- Object encapsulating MACOS device information.
- MultipartFile
-
An upload content that is a part of
MultipartRequest. This doesn't need to correspond to a physical file. - NPPIHeaderPosition
- NullToEmptyStringConverter
- Options
- The configuration for a single request. BaseOptions and Options will be merged into one RequestOptions before sending the requests. See Options.compose.
- OrderApiProvider
- OrderEndpoints
- OrderRepo
- OrderTitle
- PackingInstruction
- PHBundle
- POEndpoints
- POHistory
- ProcessOrder
- ProcessOrderDetails
- PurchaseOrderConfirmation
- PurchaseOrderItem
- QueuedInterceptor
- Interceptor in queue.
- QueuedInterceptorsWrapper
- A helper class to create QueuedInterceptor in ease.
- RawMaterialApiProvider
- RawMaterialDoc
- RawMaterialDto
- RawMaterialRepo
- RawMaterialReservationItem
- RawMaterials
- RedirectRecord
- A record that records the redirection happens during requests, including status code, request method, and the location.
- RefreshChecklistButton
- RequestInterceptorHandler
- The handler for interceptors to handle before the request has been sent.
- RequestOptions
- The internal request option class that is the eventual result after BaseOptions and Options are composed.
-
Response<
T> - The Response class contains the payload (could be transformed) that respond from the request, and other information of the response.
- ResponseBody
- The response wrapper class for adapters.
- ResponseInterceptorHandler
- The handler for interceptors to handle after respond.
- RetryInterceptor
- An interceptor that will try to send failed request again
- SapErrorMessage
- A class representing an SAP error message.
- SAPMessage
- SaveCheckpointsModalLayout
- ScanData
- ScanInterpreter
- ScannerKeyboardInterceptorService
-
Returns a Stream of BarcodeData which includes latest scanned object.
Create an instance of a ScannerKeyboardInterceptorService and then call
initHardwareHandlerAndGetStream to start listening to the HardwareKeyboard
then call
scanStreamto get the Stream. - ScheduleLine
- SecuredStorage
- SegmentedConfirmationModalLayout
- The Linux implementation of SharePlatform.
-
The fallback Windows implementation of
SharePlatform, for older Windows versions. - The result of a share to determine what action the user has taken.
- Shipment
- ShipmentApiProvider
- ShipmentEndpoints
- ShipmentItem
- ShipmentRepo
- Shipments
- SignatureField
- SourceIdentifier
- SpecialProcessConverter
- SSCCUnitDto
- StorageLocationData
- SyncTransformer
- If you want to custom the transformation of request/response data, you can provide a Transformer by your self, and replace the transformer by setting the Dio.transformer.
- ToDeliveryHeadPartner
- ToHandlingUnit
- ToItem
- ToMaterial
- ToPickQuantity
- ToPickStatus
- ToText
- Transformer
- Transformer allows changes to the request/response data before it is sent/received to/from the server.
- UnifiedHardwareScanService
-
Check
Readme.mdif you needHoneywellsupport! Detects zebra, honeywell, isafe or others (keyboard) and provides a barcode in return if scanning has happened - Unit
- UnitOfMeasures
- UnitOfMeasuresDetails
- UnitOfMeasuresDto
- UnitTileData
- UOMProvider
- UOMService
- UpdateDeliveryData
- UppercaseTextInputFormatter
- User
- UserSession
- ValidationContainer
- WebBrowserInfo
-
Information derived from
navigator. - WebViewConfiguration
- Additional configuration options for LaunchMode.inAppWebView.
- WindowsDeviceInfo
- Object encapsulating WINDOWS device information.
- XFile
- A CrossFile is a cross-platform, simplified File abstraction.
Enums
- AttachmentPickOption
- BarcodeId
- BrowserName
- List of supported browsers
- ChecklistGroupStatus
- ChecklistType
- CheckpointEditingStatus
- CheckpointStatus
- CheckpointType
- CheckpointValidationError
- CheckpointVerificationRule
- CheckpointVerificationType
- CupertinoActivityType
- Represents iOS-supported share activity types, such as AirDrop, Messages, Mail, and others.
- DioExceptionType
- The exception enumeration indicates what type of exception has happened during requests.
- FileAccessMode
- The file access mode when downloading a file, corresponds to a subset of dart:io::FileMode.
- GS1AICodes
- ItemIdType
- LaunchMode
- The desired mode to launch a URL.
- ListFormat
- Specifies the array format (a single parameter with multiple parameter or multiple parameters with the same name). and the separator for array items.
- LoadDocSearchField
- PackingFunction
- ProcessType
- ResponseType
- Indicates which transformation should be applied to the response data.
- How the user handled the share-sheet
- SpecialProcess
- UnitAssignStatus
- UnitServer
- UnitType
- UserType
Mixins
- DeliveryCalculations
- OptionsMixin
- The mixin class for options that provides common attributes.
Extensions
- ApiResponseExceptionPatterns on ApiResponseException
- Adds pattern-matching-related methods to ApiResponseException.
-
AttributeCheck
on Map<
String, dynamic> - AuthCredentialsPatterns on AuthCredentials
- Adds pattern-matching-related methods to AuthCredentials.
-
CalculationExtension
on List<
NPPIHeaderPosition> - ChecklistCatalogDocumentPatterns on ChecklistCatalogDocument
- Adds pattern-matching-related methods to ChecklistCatalogDocument.
- ChecklistCatalogStatePatterns on ChecklistCatalogState
- Adds pattern-matching-related methods to ChecklistCatalogState.
- ChecklistCatalogStateX on ChecklistCatalogState
- ChecklistDebugStatePatterns on ChecklistDebugState
- Adds pattern-matching-related methods to ChecklistDebugState.
- ChecklistDocPatterns on ChecklistDoc
- Adds pattern-matching-related methods to ChecklistDoc.
- ChecklistDtoPatterns on ChecklistDto
- Adds pattern-matching-related methods to ChecklistDto.
- ChecklistPatterns on Checklist
- Adds pattern-matching-related methods to Checklist.
- ChecklistReservationItemPatterns on ChecklistReservationItem
- Adds pattern-matching-related methods to ChecklistReservationItem.
- ChecklistSearchStatePatterns on ChecklistSearchState
- Adds pattern-matching-related methods to ChecklistSearchState.
- CheckpointAttachmentPatterns on CheckpointAttachment
- Adds pattern-matching-related methods to CheckpointAttachment.
- CheckpointExtension on Checkpoint
- CheckpointListValuePatterns on CheckpointListValue
- Adds pattern-matching-related methods to CheckpointListValue.
- CheckpointPatterns on Checkpoint
- Adds pattern-matching-related methods to Checkpoint.
- CheckpointsGroupDtoPatterns on CheckpointsGroupDto
- Adds pattern-matching-related methods to CheckpointsGroupDto.
- CheckpointsGroupPatterns on CheckpointsGroup
- Adds pattern-matching-related methods to CheckpointsGroup.
- CheckpointsGroupsStatePatterns on CheckpointsGroupsState
- Adds pattern-matching-related methods to CheckpointsGroupsState.
- CheckpointSignaturePatterns on CheckpointSignature
- Adds pattern-matching-related methods to CheckpointSignature.
- CheckpointsManagementStatePatterns on CheckpointsManagementState
- Adds pattern-matching-related methods to CheckpointsManagementState.
- ConvertToUnit on UnitOfMeasuresDto
- DateTimeFormatters on DateTime?
- DeliveryBundlePatterns on DeliveryBundle
- Adds pattern-matching-related methods to DeliveryBundle.
- DeliveryExtension on Delivery
- DeliveryItemExtension on ToItem
-
DeliveryListExtension
on List<
Delivery> - DeliveryPatterns on Delivery
- Adds pattern-matching-related methods to Delivery.
- FormatDouble on double
- GetUserType on User
- GoodsReceiptRequirementPatterns on GoodsReceiptRequirement
- Adds pattern-matching-related methods to GoodsReceiptRequirement.
- HttpExtensions on Response
- HuCreationDataPatterns on HuCreationData
- Adds pattern-matching-related methods to HuCreationData.
- HuDetailsExtension on HuDetails?
-
HuDetailsListExtension
on List<
HuDetails?> - HuDetailsPatterns on HuDetails
- Adds pattern-matching-related methods to HuDetails.
- HuHistoryPatterns on HuHistory
- Adds pattern-matching-related methods to HuHistory.
- HuItemExtension on HuItem
- HuItemPackDataPatterns on HuItemPackData
- Adds pattern-matching-related methods to HuItemPackData.
- HuItemPatterns on HuItem
- Adds pattern-matching-related methods to HuItem.
- HuPackDataPatterns on HuPackData
- Adds pattern-matching-related methods to HuPackData.
- HuStatusPatterns on HuStatus
- Adds pattern-matching-related methods to HuStatus.
- InnerChecklistPatterns on InnerChecklist
- Adds pattern-matching-related methods to InnerChecklist.
- ItemUnitDtoExtension on ItemUnitDto
- ItemUnitDtoPatterns on ItemUnitDto
- Adds pattern-matching-related methods to ItemUnitDto.
- LoadDocDeliveryHandlingUnitPatterns on LoadDocDeliveryHandlingUnit
- Adds pattern-matching-related methods to LoadDocDeliveryHandlingUnit.
- LoadDocDeliveryItemPatterns on LoadDocDeliveryItem
- Adds pattern-matching-related methods to LoadDocDeliveryItem.
- LoadDocDocPatterns on LoadDocDoc
- Adds pattern-matching-related methods to LoadDocDoc.
- LoadDocsPatterns on LoadDocs
- Adds pattern-matching-related methods to LoadDocs.
- LoadDocTransportRelatedDeliveryPatterns on LoadDocTransportRelatedDelivery
- Adds pattern-matching-related methods to LoadDocTransportRelatedDelivery.
- LoginCredentialsPatterns on LoginCredentials
- Adds pattern-matching-related methods to LoginCredentials.
- NPPIHeaderPositionPatterns on NPPIHeaderPosition
- Adds pattern-matching-related methods to NPPIHeaderPosition.
- NullableStringExtension on String?
- OptionsX on Options
- PackingInstructionPatterns on PackingInstruction
- Adds pattern-matching-related methods to PackingInstruction.
-
ParseExtension
on List<
GS1ParsedElement> - PHBundlePatterns on PHBundle
- Adds pattern-matching-related methods to PHBundle.
- POHistoryPatterns on POHistory
- Adds pattern-matching-related methods to POHistory.
- POItemExtension on PurchaseOrderItem
- ProcessOrderDetailsPatterns on ProcessOrderDetails
- Adds pattern-matching-related methods to ProcessOrderDetails.
- ProcessOrderPatterns on ProcessOrder
- Adds pattern-matching-related methods to ProcessOrder.
-
PurchaseItemlistExtension
on List<
PurchaseOrderItem> - PurchaseOrderConfirmationPatterns on PurchaseOrderConfirmation
- Adds pattern-matching-related methods to PurchaseOrderConfirmation.
- PurchaseOrderItemPatterns on PurchaseOrderItem
- Adds pattern-matching-related methods to PurchaseOrderItem.
- RawMaterialDocPatterns on RawMaterialDoc
- Adds pattern-matching-related methods to RawMaterialDoc.
- RawMaterialDtoPatterns on RawMaterialDto
- Adds pattern-matching-related methods to RawMaterialDto.
- RawMaterialReservationItemPatterns on RawMaterialReservationItem
- Adds pattern-matching-related methods to RawMaterialReservationItem.
- RawMaterialsPatterns on RawMaterials
- Adds pattern-matching-related methods to RawMaterials.
- RequestOptionsX on RequestOptions
- ResponseExtension on Response?
- SAPMessagePatterns on SAPMessage
- Adds pattern-matching-related methods to SAPMessage.
- ScanDataExtension on ScanData
- ScheduleLinePatterns on ScheduleLine
- Adds pattern-matching-related methods to ScheduleLine.
- ShowError on AppException
- SourceIdentifierPatterns on SourceIdentifier
- Adds pattern-matching-related methods to SourceIdentifier.
- SSCCDtoExtension on SSCCUnitDto
- SSCCExtension on UnitSSCC
-
SSCCListExtension
on List<
UnitSSCC> - SSCCUnitDtoPatterns on SSCCUnitDto
- Adds pattern-matching-related methods to SSCCUnitDto.
- StorageLocationDataPatterns on StorageLocationData
- Adds pattern-matching-related methods to StorageLocationData.
-
StreamDebounce
on Stream<
T> - StringExtension on String
- ToDeliveryHeadPartnerPatterns on ToDeliveryHeadPartner
- Adds pattern-matching-related methods to ToDeliveryHeadPartner.
- ToHandlingUnitPatterns on ToHandlingUnit
- Adds pattern-matching-related methods to ToHandlingUnit.
- ToItemPatterns on ToItem
- Adds pattern-matching-related methods to ToItem.
- ToMaterialPatterns on ToMaterial
- Adds pattern-matching-related methods to ToMaterial.
- ToPickQuantityPatterns on ToPickQuantity
- Adds pattern-matching-related methods to ToPickQuantity.
- ToPickStatusPatterns on ToPickStatus
- Adds pattern-matching-related methods to ToPickStatus.
- ToTextPatterns on ToText
- Adds pattern-matching-related methods to ToText.
- UnitExtension on Unit
- UnitOfMeasuresDetailsPatterns on UnitOfMeasuresDetails
- Adds pattern-matching-related methods to UnitOfMeasuresDetails.
- UnitOfMeasuresDtoPatterns on UnitOfMeasuresDto
- Adds pattern-matching-related methods to UnitOfMeasuresDto.
- UnitOfMeasuresPatterns on UnitOfMeasures
- Adds pattern-matching-related methods to UnitOfMeasures.
- UnitPatterns on Unit
- Adds pattern-matching-related methods to Unit.
- UnitStringExtension on String
- UnitTileDataPatterns on UnitTileData
- Adds pattern-matching-related methods to UnitTileData.
- UnitWhiteExtension on UnitItem
- UserPatterns on User
- Adds pattern-matching-related methods to User.
- UserSessionPatterns on UserSession
- Adds pattern-matching-related methods to UserSession.
Constants
-
defaultRetryableStatuses
→ const Set<
int> -
retryableStatuses
→ const Set<
int> - status100Continue → const int
- status101SwitchingProtocols → const int
- status102Processing → const int
- status200OK → const int
- status201Created → const int
- status202Accepted → const int
- status203NonAuthoritative → const int
- status204NoContent → const int
- status205ResetContent → const int
- status206PartialContent → const int
- status207Multistatus → const int
- status208AlreadyReported → const int
- status226IMUsed → const int
- status300MultipleChoices → const int
- status301MovedPermanently → const int
- status302Found → const int
- status303SeeOther → const int
- status304NotModified → const int
- status305UseProxy → const int
- status306SwitchProxy → const int
- status307TemporaryRedirect → const int
- status308PermanentRedirect → const int
- status400BadRequest → const int
- status402PaymentRequired → const int
- status403Forbidden → const int
- status404NotFound → const int
- status405MethodNotAllowed → const int
- status406NotAcceptable → const int
- status407ProxyAuthenticationRequired → const int
- status408RequestTimeout → const int
- status409Conflict → const int
- status410Gone → const int
- status411LengthRequired → const int
- status412PreconditionFailed → const int
- status413PayloadTooLarge → const int
- status413RequestEntityTooLarge → const int
- status414RequestUriTooLong → const int
- status414UriTooLong → const int
- status415UnsupportedMediaType → const int
- status416RangeNotSatisfiable → const int
- status416RequestedRangeNotSatisfiable → const int
- status417ExpectationFailed → const int
- status418ImATeapot → const int
- status419AuthenticationTimeout → const int
- status421MisdirectedRequest → const int
- status422UnprocessableEntity → const int
- status423Locked → const int
- status424FailedDependency → const int
- status426UpgradeRequired → const int
- status428PreconditionRequired → const int
- status429TooManyRequests → const int
- status431RequestHeaderFieldsTooLarge → const int
- status440LoginTimeout → const int
- From IIS
- status460ClientClosedRequest → const int
- From AWS Elastic Load Balancer
- status499ClientClosedRequest → const int
- From ngnix
- status500InternalServerError → const int
- status501NotImplemented → const int
- status502BadGateway → const int
- status504GatewayTimeout → const int
- status505HttpVersionNotSupported → const int
- status506VariantAlsoNegotiates → const int
- status507InsufficientStorage → const int
- status508LoopDetected → const int
- status510NotExtended → const int
- status511NetworkAuthenticationRequired → const int
- status520WebServerReturnedUnknownError → const int
- status521WebServerIsDown → const int
- status522ConnectionTimedOut → const int
- status523OriginIsUnreachable → const int
- status524TimeoutOccurred → const int
- status525SSLHandshakeFailed → const int
- status526InvalidSSLCertificate → const int
- status527RailgunError → const int
- status598NetworkReadTimeoutError → const int
- status599NetworkConnectTimeoutError → const int
- xmlRequestError → const String
Functions
-
alternative(
String pattern1, String pattern2) → String -
canLaunch(
String urlString) → Future< bool> - Checks whether the specified URL can be handled by some app installed on the device.
-
canLaunchUrl(
Uri url) → Future< bool> - Checks whether the specified URL can be handled by some app installed on the device.
-
closeInAppWebView(
) → Future< void> - Closes the current in-app web view, if one was previously opened by launchUrl.
-
closeWebView(
) → Future< void> - Closes the current WebView, if one was previously opened via a call to launch.
-
defaultDioExceptionReadableStringBuilder(
DioException e) → String - The default implementation of building a readable string of DioException.
-
isRetryable(
int statusCode) → bool - Be careful: this method do not take into account RetryInterceptor.retryableExtraStatuses
-
launch(
String urlString, {bool? forceSafariVC, bool forceWebView = false, bool enableJavaScript = false, bool enableDomStorage = false, bool universalLinksOnly = false, Map< String, String> headers = const <String, String>{}, Brightness? statusBarBrightness, String? webOnlyWindowName}) → Future<bool> - Parses the specified URL string and delegates handling of it to the underlying platform.
-
launchUrl(
Uri url, {LaunchMode mode = LaunchMode.platformDefault, WebViewConfiguration webViewConfiguration = const WebViewConfiguration(), BrowserConfiguration browserConfiguration = const BrowserConfiguration(), String? webOnlyWindowName}) → Future< bool> -
Passes
urlto the underlying platform for handling. -
lookupBasfLogicLocalizations(
Locale locale) → BasfLogicLocalizations -
namedGroup(
{required String pattern, required String name}) → String -
supportsCloseForLaunchMode(
LaunchMode mode) → Future< bool> -
Returns true if closeInAppWebView is supported for
modein the current platform implementation. -
supportsLaunchMode(
LaunchMode mode) → Future< bool> -
Returns true if
modeis supported by the current platform implementation.
Typedefs
- DefaultTransformer = SyncTransformer
- DioError = DioException
- DioError describes the exception info when a request failed.
- DioErrorType = DioExceptionType
- Deprecated in favor of DioExceptionType and will be removed in future major versions.
- DioExceptionReadableStringBuilder = String Function(DioException e)
- The readable string builder's signature of DioException.readableStringBuilder.
- DioMediaType = MediaType
-
The type (alias) for specifying the content-type of the
MultipartFile. -
HeaderForEachCallback
= void Function(String name, List<
String> values) - The signature that iterates header fields.
- InterceptorErrorCallback = void Function(DioException error, ErrorInterceptorHandler handler)
- The signature of Interceptor.onError.
- InterceptorSendCallback = void Function(RequestOptions options, RequestInterceptorHandler handler)
- The signature of Interceptor.onRequest.
- InterceptorSuccessCallback = void Function(Response response, ResponseInterceptorHandler handler)
- The signature of Interceptor.onResponse.
-
Json
= Map<
String, dynamic> - JsonDecodeCallback = FutureOr Function(String)
- The callback definition for decoding a JSON string.
-
JsonEncodeCallback
= FutureOr<
String> Function(Object) - The callback definition for encoding a JSON object.
- ProgressCallback = void Function(int count, int total)
- The type of a progress listening callback when sending or receiving data.
-
RequestEncoder
= FutureOr<
List< Function(String request, RequestOptions options)int> > - The type of a request encoding callback.
-
ResponseDecoder
= FutureOr<
String?> Function(List<int> responseBytes, RequestOptions options, ResponseBody responseBody) - The type of a response decoding callback.
-
RetryEvaluator
= FutureOr<
bool> Function(DioException error, int attempt) - ValidateStatus = bool Function(int? status)
- The type of a response status code validate callback.
Exceptions / Errors
- ApiResponseException
- AppException
- DioException
- DioException describes the exception info when a request failed.
- KnownException
-
NotNullableError<
T> -
A TypeError thrown by
_checkNotNullable. - ScanInterpretationException
- SessionException
- UnknownException
- XMLHttpRequestException