ItemUnitDto class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- ItemUnitDto({@JsonKey.new(includeToJson: false) required String itemId, @JsonKey.new(includeToJson: false) required String itemVersion, @ItemIdTypeJsonConverter() required ItemIdType idType, required String user, required SourceIdentifier sourceIdentifier, @Default.new('') @JsonKey.new(includeToJson: false) String unitId, @SpecialProcessConverter() @JsonKey.new(includeToJson: false) SpecialProcess? specialProcess, @Default.new(0) @JsonKey.new(includeToJson: false) double weightFilled, @JsonKey.new(includeToJson: false) DateTime? capturedAt, @JsonKey.new(includeToJson: false) DateTime? createdAt})
-
constfactory
-
ItemUnitDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- capturedAt → DateTime?
-
no setterinherited
-
copyWith
→ $ItemUnitDtoCopyWith<
ItemUnitDto> -
Create a copy of ItemUnitDto
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- idType → ItemIdType
-
no setterinherited
- itemId → String
-
no setterinherited
- itemVersion → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceIdentifier → SourceIdentifier
-
no setterinherited
- specialProcess → SpecialProcess?
-
no setterinherited
- unitId → String
-
no setterinherited
- user → String
-
no setterinherited
- weightFilled → double
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ItemUnitDto value)) → TResult -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ItemUnitDto value)?) → TResult? -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ItemUnitDto value)?, {required TResult orElse()}) → TResult -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String itemId, String itemVersion, ItemIdType idType, String user, SourceIdentifier sourceIdentifier, String unitId, SpecialProcess? specialProcess, double weightFilled, DateTime? capturedAt, DateTime? createdAt)?, {required TResult orElse()}) → TResult -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ItemUnitDto to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toUnitItem(
{UnitServer? server}) → UnitItem -
Available on ItemUnitDto, provided by the ItemUnitDtoExtension extension
-
when<
TResult extends Object?> (TResult $default(String itemId, String itemVersion, ItemIdType idType, String user, SourceIdentifier sourceIdentifier, String unitId, SpecialProcess? specialProcess, double weightFilled, DateTime? capturedAt, DateTime? createdAt)) → TResult -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String itemId, String itemVersion, ItemIdType idType, String user, SourceIdentifier sourceIdentifier, String unitId, SpecialProcess? specialProcess, double weightFilled, DateTime? capturedAt, DateTime? createdAt)?) → TResult? -
Available on ItemUnitDto, provided by the ItemUnitDtoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited